@@ -82,6 +82,9 @@ class Resources(object):
     _inventory_variable_data = r'inventories/\d+/variable_data/'
     _workflow_approval = r'workflow_approvals/\d+/'
     _workflow_approvals = 'workflow_approvals/'
+    _workflow_approval_template = r'workflow_approval_templates/\d+/'
+    _workflow_approval_templates = 'workflow_approval_templates/'
+    _workflow_job_template_node_create_approval_template = r'workflow_job_template_nodes/\d+/create_approval_template/'
     _job = r'jobs/\d+/'
     _job_cancel = r'jobs/\d+/cancel/'
     _job_create_schedule = r'jobs/\d+/create_schedule/'
